import React, { memo, useMemo } from 'react';
import _ from 'lodash';
import { BasicChart } from '@wisdom-components/basicchart';
import optionGenerator from './utils';

const GridChart = memo((props) => {
  const {
    dataSource,
    contrast = false,
    contrastOption = 'day',
    smooth = true,
    curveCenter,
  } = props;
  const { prefixCls } = props;

  const gridData = useMemo(() => {
    const grids = dataSource.reduce((pre, item, index) => {
      const { sensorName, deviceType } = item;
      const key = `${deviceType}_${sensorName}`; // 同设备类型同指标才在同一组
      let grid = pre.find((g) => g.key === key);
      if (!grid) {
        const restProp = _.pick(item, ['equipmentName', 'sensorName', 'stationCode', 'unit']);
        grid = {
          key: key,
          list: [],
          ...restProp,
        };
        pre.push(grid);
      }
      grid.list.push(item);
      return pre;
    }, []);
    return grids;
  }, [dataSource]);

  const options = useMemo(() => {
    return gridData.map((item) => {
      const { key, list, equipmentName, sensorName, stationCode, unit } = item;
      const cusOption = {
        title: {
          show: true,
          text: `{prefix|}{t|${sensorName}}${unit ? '{suffix|（单位：' + unit + '）}' : ''}`,
          textStyle: {
            width: 200,
            overflow: 'truncate',
          },
        },
        legend: {
          // orient: 'vertical',
          itemGap: 10,
          padding: [0, 0, 0, 200],
          textStyle: {
            width: 120,
            overflow: 'truncate',
          },
        },
      };
      const option = optionGenerator(list, cusOption, contrast, contrastOption, smooth, {
        curveCenter,
      });
      return {
        key,
        option: option,
      };
    });
  }, [gridData, smooth, curveCenter]);

  return (
    <div className={`${prefixCls}-grid`}>
      {options.map((item) => (
        <div key={item.key} className={`${prefixCls}-grid-item`}>
          <div className={`${prefixCls}-grid-item-wrap`}>
            <BasicChart style={{ width: '100%', height: '100%' }} option={item.option} notMerge />
          </div>
        </div>
      ))}
    </div>
  );
});

export default GridChart;
